@@ -3,18 +3,18 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20140131';
+our $VERSION = '0.20140228';
 
-# Table last modified: 2014-01-31
+# Table last modified: 2014-02-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
     '003' => '(?:8(?:5(?:58|77|8[0-258]|0[1-5]|3[01]|1[0159]|6[67])|6(?:01|40|68|3[019]|1[02])|70[12]))',
-    '004' => '(?:8(?:5(?:[67]7|23|0[23]|1[028]|[58][58]|3[013])|6(?:[34]1|29|0[23]|1[0-368])))',
+    '004' => '(?:8(?:5(?:[67]7|23|0[23]|1[028]|[58][58]|3[0-3])|6(?:[34]1|29|0[23]|1[0-368])))',
     '005' => '(?:8(?:5(?:[58]5|01|43)|6(?:12|0[12])|798))',
     '006' => '(?:8(?:5(?:[58]5|61)|612))',
     '007' => '(?:8(?:5(?:85|0[13578])|632))',
-    '010' => '(?:(?:8(?:5(?:43|3[03]|1[158]|6[045]|5[058]|0[124-7]|2[05]|8[08]|7[0247])|6(?:[01]1|33|55|68|7[78]|2[12])|794)|0(?:49[2-4]|[15]95)|1(?:49[23]|292)))',
+    '010' => '(?:(?:8(?:5(?:43|3[03]|1[158]|6[045]|5[058]|0[124-7]|2[05]|8[08]|7[0247])|6(?:[01]1|22|33|55|68|7[78])|794)|0(?:49[2-4]|[15]95)|1(?:49[23]|292)))',
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
     '013' => '(?:(?:8(?:5(?:92|0[1-4])|60[129])|0498))',
@@ -91,7 +91,7 @@ our %ZIP_TABLE = (
     '085' => '(?:(?:8(?:5(?:67|1[0-25]|3[35]|2[27]|5[01578]|8[01568]|0[125])|6(?:[34]9|77|5[05]|6[08]))|029[23]))',
     '086' => '(?:1(?:89[23]|197))',
     '087' => '(?:(?:8(?:5(?:55|88)|6(?:09|86)|711)|0192))',
-    '088' => '(?:(?:0(?:39[2-5]|59[258]|19[23]|692)|1(?:19[235]|592)|3(?:39[59]|292)|259[23]))',
+    '088' => '(?:(?:0(?:39[2-5]|59[258]|19[23]|692)|1(?:19[235]|592)|3(?:292|395)|259[23]))',
     '089' => '(?:(?:1(?:19[28]|39[25]|59[25]|795)|0(?:19[258]|59[258]|69[23])|2(?:69[235-7]|195|492)|5(?:39[23]|69[25])|3(?:392|797)))',
     '090' => '(?:8(?:5(?:40|3[23]|[58][058]|6[07]|1[189]|0[1-379])|6(?:[18]0|42|66|5[025])|7(?:2[239]|1[01])))',
     '091' => '(?:(?:019[2-4]|8666))',
@@ -103,14 +103,14 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|3(?:6[2356]|0[1257-9]|4[5-7]|8[01358]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '101' => '(?:8(?:4(?:7[05-7]|8[13]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|3(?:6[2356]|0[1257-9]|4[5-7]|8[01358]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:41|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:30|77|8[0-35]|2[45]|0[58]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|6[67]|5[24-68]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|1[0-3579]|8[01368]|4[045]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:40|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-3]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|7444))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|1[0-3579]|8[01368]|4[045]|2[014589]|5[167]|6[05]|3[02358]|0[1-59])|2(?:40|1[0-258]|7[17]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-3]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|6050|7444))',
     '106' => '(?:(?:8(?:5(?:08|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|3[1257]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
+    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|8[24]|1[0-246-9]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|5[0-35-9]|6[048]|3[0236]|0[12579]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[3-57]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
@@ -118,7 +118,7 @@ our %ZIP_TABLE = (
     '112' => '(?:8(?:6(?:90|6[02-48]|0[1467]|2[02579]|4[24]|7[01578]|5[0-57]|8[0-578]|3[02-5]|1[0-28])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|7[147]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
-    '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
+    '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|622|711))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-246]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
     '120' => '(?:8(?:5(?:44|81|7[057]|0[178]|1[02]|2[068]|3[0469]|5[013568])|60[12]))',
     '121' => '(?:8(?:5(?:20|0[45]|8[58]|[15][05])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
@@ -140,7 +140,7 @@ our %ZIP_TABLE = (
     '144' => '(?:8(?:5(?:44|5[015]|8[018]|3[0-356]|7[057]|2[25]|1[01356]|0[56])|6(?:02|11|2[1-3]|5[056]|7[78]|6[01])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|5[158]|8[058]|1[0-25]|7[67]|0[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
-    '150' => '(?:8(?:5(?:45|5[015]|6[37]|2[25]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|6[37]|2[25]|5[0-25]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:7[1-7]|0[01])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|7[1378]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
@@ -162,7 +162,7 @@ our %ZIP_TABLE = (
     '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|6[0-256]|7[067]|5[015-9]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
     '171' => '(?:85(?:5[23578]|3[19]|7[027]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|8[0268]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
-    '174' => '(?:8(?:5(?:30|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
+    '174' => '(?:8(?:5(?:[13]0|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:71|88))',
     '176' => '(?:85(?:[46]0|85|1[0-2568]|2[1258]|3[013-6]|0[1-378]))',
     '177' => '(?:85(?:21|0[1-389]))',
@@ -186,7 +186,7 @@ our %ZIP_TABLE = (
     '195' => '(?:85(?:85|5[05]))',
     '196' => '(?:8(?:5(?:01|22|5[058]|8[58]|1[01])|6(?:[01]1|86|6[68])))',
     '197' => '(?:8(?:5(?:[01]1|55)|6(?:01|23)))',
-    '198' => '(?:8(?:5(?:31|55|77|2[25]|1[02]|8[58])|7(?:22|60|[01][01])|6(?:[018]1|55|66)))',
+    '198' => '(?:8(?:5(?:31|55|77|2[25]|1[02]|8[58])|7(?:22|60|[01][01])|6(?:[01]1|55|66)))',
     '201' => '(?:8(?:5(?:[01]1|8[58])|6(?:01|48|86)))',
     '202' => '(?:85(?:20|85|5[58]))',
     '203' => '(?:8(?:5(?:[12]1|55|8[58])|601|739))',
@@ -195,9 +195,9 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[167]|0[235]|5[05]|1[125])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
-    '210' => '(?:(?:8(?:5(?:2[1-3]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|5[127-9]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
+    '210' => '(?:(?:8(?:5(?:2[1-3]|0[246]|6[0259]|3[1278]|7[067]|1[12]|8[36]|5[127-9]|4[014578])|6(?:04|66|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
     '211' => '(?:8(?:5(?:[2-4]0|66|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|75|1[19]|6[68])))',
-    '212' => '(?:8(?:5(?:44|90|8[1-589]|1[13]|6[03467]|2[05]|7[0267]|5[1457]|3[01]|0[1-3589])|602))',
+    '212' => '(?:8(?:5(?:11|0[12589]|6[03467]|2[05]|7[0267]|5[1457]|8[1-59]|3[01])|602))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]|4[56]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
@@ -214,7 +214,7 @@ our %ZIP_TABLE = (
     '231' => '(?:8(?:3(?:43|3[018]|2[0134]|1[0-6])|5(?:[25]0|42|6[26]|3[46]|8[08])|4(?:[38]4|45|61|1[19]|7[078])|0(?:80|0[18])|6(?:16|54|82)|7(?:11|7[12])|966))',
     '232' => '(?:8(?:5(?:15|31|76|8[057]|5[58])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
-    '235' => '(?:85(?:[58]8|2[23]|0[15]))',
+    '235' => '(?:85(?:58|2[23]|0[15]))',
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
     '238' => '(?:(?:8(?:5(?:8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
@@ -239,8 +239,8 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|392)|0(?:1(?:9[2-46-8]|8[01])|39[2356])))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|2[134]|8[0568]|7[257]|0[1-9]|3[2458]|1[0-68]|5[0-24-9]|6[02-7])|7(?:3[03]|1[02357]|2[02]|0[1-37])))',
-    '261' => '(?:8(?:5(?:66|75|3[03]|4[45]|5[2458]|1[0235]|2[0-2]|0[1-378]|8[125-8])|6(?:09|86)|733))',
+    '260' => '(?:8(?:6(?:0[13467]|5[46]|4[2578]|2[0-24679]|6[0-35-8]|7[0-357]|8[258]|3[135-7]|1[02389])|5(?:40|2[134]|8[0568]|7[257]|0[1-9]|3[2458]|1[0-68]|5[01457-9]|6[02-7])|7(?:3[03]|1[02357]|0[137]|2[02])))',
+    '261' => '(?:8(?:5(?:66|75|3[03]|4[45]|5[2458]|1[0235]|0[1-478]|2[0-2]|8[125-8])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:1[0-2]|0[236])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
@@ -304,7 +304,7 @@ our %ZIP_TABLE = (
     '328' => '(?:(?:8(?:5(?:33|5[0568]|8[568]|0[1-5])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:59[568]|49[28]|69[26]|195)|1(?:19[3-68]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[23]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|6[4-6]|3[156]|2[35]|7[57]|1[0-2]|0[1-37-9]|8[0-3568])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:01|30|77|1[01])|7(?:15|9[67])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|8[015]|0[3568]|3[238]|1[0189]|2[29]|7[129]|5[01]|6[56])|6(?:01|69|8[68])|710)))',
-    '331' => '(?:(?:8(?:5(?:[24]0|01|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:33|58|8[6-8]))|9(?:5(?:[1-35]0|77)|624)))',
+    '331' => '(?:(?:8(?:5(?:[24]0|[01][13]|8[05-8]|5[02]|6[07]|3[237])|6(?:33|58|8[6-8]))|9(?:5(?:[1-35]0|77)|624)))',
     '332' => '(?:8(?:5(?:21|33|48|77|85|5[568]|[01][12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
     '334' => '(?:8501)',
@@ -353,7 +353,7 @@ our %ZIP_TABLE = (
     '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|19[235]|29[2-4]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[01457]|9[2-578])|39[258]|29[28])|1(?:[16]92|[24]98|393)|0(?:19[2356]|292)))',
-    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|0[1-8]|7[0235-7]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|0[158]|2[25]|3[0359]|8[268]|6[068]|4[08]|1[0-24])|79[4-8]))',
+    '380' => '(?:8(?:5(?:0[1-35-8]|8[013-689]|7[0235-7]|6[015-8]|2[0-24-6]|5[0-3578]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|77|0[158]|2[25]|3[0359]|8[268]|6[068]|4[08]|1[0-24])|79[4-8]))',
     '381' => '(?:(?:8(?:5(?:1[015]|[67][07]|3[09]|0[138]|4[58]|2[05]|8[08]|5[68])|6(?:02|86)|793)|0(?:29[23578]|19[23]|49[78])|22(?:8[0-35-8]|9[258])|4(?:19[23]|393)))',
     '382' => '(?:8(?:5(?:33|55|0[128]|8[578]|1[0-2])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
@@ -426,7 +426,7 @@ our %ZIP_TABLE = (
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[124]))',
     '453' => '(?:8(?:5(?:40|55|77|8[015]|3[39]|1[0-258]|6[57]|2[12]|0[15])|6(?:[01]1|62|86)|7(?:58|65|77)))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
-    '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[01458]5|21|30)))',
+    '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[01458]5|21|3[05])))',
     '456' => '(?:8(?:5(?:23|30|6[07]|1[16]|8[0578]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
     '457' => '(?:8(?:5(?:[48]5|22|77|3[0-35]|5[158]|1[0-25]|6[067]|0[18])|71[12]))',
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
@@ -652,7 +652,7 @@ our %ZIP_TABLE = (
     '691' => '(?:860[12])',
     '692' => '(?:8(?:5(?:[15]0|06)|6(?:86|0[16])))',
     '693' => '(?:8(?:5(?:01|23|66|3[013]|5[05]|8[57]|1[01])|6(?:01|14|86)))',
-    '694' => '(?:8501)',
+    '694' => '(?:850[12])',
     '695' => '(?:85(?:77|85|0[125]))',
     '696' => '(?:(?:0(?:19[2358]|393|692)|8510))',
     '697' => '(?:(?:8(?:5(?:01|85|1[12])|686|789)|0492))',
@@ -772,7 +772,7 @@ our %ZIP_TABLE = (
     '813' => '(?:8(?:5(?:29|33|68|1[39]|7[78]|0[13]|8[58])|6(?:2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:77|0[135]|2[025]|6[57]|8[589]|1[0-2]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:11|33|88|4[06]|0[13]|2[09]|5[05])|6(?:[68]6|01)))',
-    '816' => '(?:8(?:5(?:[13]0|[67]7|01|[58][05])|666))',
+    '816' => '(?:8(?:5(?:[67]7|01|30|[58][05]|1[01])|666))',
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
     '818' => '(?:(?:8(?:5(?:16|55|67|0[1-3]|7[178]|4[09]|8[58])|6(?:42|86|6[68]))|019[2-578]))',
     '819' => '(?:(?:85(?:11|33|85|5[0-258]|0[124])|1(?:19[235]|[36]92)|0(?:19[23]|395)))',
@@ -874,7 +874,7 @@ our %ZIP_TABLE = (
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
     '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|0[1-358]|8[03568])|68[168]))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
-    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|8[01568]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[17]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
+    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[17]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|8[0-489]|0[15-8]|2[035-79]|4[1468]|7[1-79])|6(?:01|50|3[079]|1[126]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|4[2-46]|1[0156]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
@@ -950,7 +950,7 @@ our %ZIP_TABLE = (
     '996' => '(?:8(?:501|602))',
     '997' => '(?:(?:8(?:5(?:01|67|2[23]|[58][58]|1[15])|6(?:[01]1|55))|0(?:29[26]|[14]92)|1392))',
     '998' => '(?:(?:8(?:5(?:[14]0|8[058]|5[05]|0[12])|6(?:11|33))|019[24]))',
-    '999' => '(?:(?:3(?:79[25-79]|19[23]|292)|7(?:69[56]|292)|0(?:193|696)|[1458]292|229[23]))',
+    '999' => '(?:(?:3(?:79[25-7]|19[23]|292)|7(?:69[56]|292)|0(?:193|696)|[1458]292|229[23]))',
 );
 
 1;
